@@ -68,7 +68,7 @@ func FuzzDecodeTIFF(f *testing.F) {
 
 func fuzzDecodeBytes(t *testing.T, imageBytes []byte, f imagemeta.ImageFormat) error {
 	r := bytes.NewReader(imageBytes)
-	err := imagemeta.Decode(imagemeta.Options{R: r, ImageFormat: f, Sources: imagemeta.EXIF | imagemeta.IPTC | imagemeta.XMP, Timeout: 600 * time.Millisecond})
+	_, err := imagemeta.Decode(imagemeta.Options{R: r, ImageFormat: f, Sources: imagemeta.EXIF | imagemeta.IPTC | imagemeta.XMP, Timeout: 600 * time.Millisecond})
 	if err != nil {
 		if !imagemeta.IsInvalidFormat(err) && !strings.Contains(err.Error(), "timed out") {
 			t.Fatalf("unknown error in Decode: %v %T", err, err)
